==> tw-api-5.0.36-20240713.154615-1-sources.jar: com/elitesland/tw/tw5/api/prd/personplan/vo/PersonPlanVersionVO.java <==
package com.elitesland.tw.tw5.api.prd.personplan.vo;

import com.elitescloud.boot.common.param.BaseViewModel;
import com.elitesland.tw.tw5.api.udc.UdcName;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;


/**
 * 人员规划版本
 *
 * @author wangly
 * @date 2024-04-07
 */
@Getter
@Setter
public class PersonPlanVersionVO extends BaseViewModel implements Serializable {

    /**
     * 资源规划主表id
     */
    @ApiModelProperty("资源规划主表id")
    private Long planId;
    /**
     * 类型
     */
    @ApiModelProperty("类型")
    private String planType;
    /**
     * 版本名称
     */
    @ApiModelProperty("版本名称")
    private String versionName;
    /**
     * 版本信息
     */
    @ApiModelProperty("版本信息")
    private String changeContent;
    /**
     * 变更单据id
     */
    @ApiModelProperty("变更单据id")
    private Long objId;
    /**
     * 版本号
     */
    @ApiModelProperty("版本号")
    private Integer versionNo;
    /**
     * 变更状态
     */
    @ApiModelProperty("变更状态")
    private String status;
    /**
     * 流程状态
     */
    @ApiModelProperty("流程状态")
    private String apprStatus;
    /**
     * 流程实例ID
     */
    @ApiModelProperty("流程实例ID")
    private String apprProcInstId;
    private String extString1;
    private String extString2;
    private String extString3;
    private String extString4;
    private String extString5;

    private PersonPlanVO personPlanVO;

    /**
     * 记录创建者ID
     */
    @ApiModelProperty("记录创建者ID")
    private Long createUserId;

    /**
     * 记录创建者名称
     */
    @ApiModelProperty("记录创建者名称")
    @UdcName(udcName = "USER",codePropName ="createUserId")
    private String createUserName;


}

==> tw-api-5.1.43-20240813.085006-1-sources.jar: com/elitesland/tw/tw5/api/prd/personplan/vo/PersonPlanVersionVO.java <==
package com.elitesland.tw.tw5.api.prd.personplan.vo;

import com.elitescloud.boot.common.param.BaseViewModel;
import com.elitesland.tw.tw5.api.udc.UdcName;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;


/**
 * 人员规划版本
 *
 * @author wangly
 * @date 2024-04-07
 */
@Getter
@Setter
public class PersonPlanVersionVO extends BaseViewModel implements Serializable {

    /**
     * 资源规划主表id
     */
    @ApiModelProperty("资源规划主表id")
    private Long planId;
    /**
     * 类型
     */
    @ApiModelProperty("类型")
    private String planType;
    /**
     * 版本名称
     */
    @ApiModelProperty("版本名称")
    private String versionName;
    /**
     * 版本信息
     */
    @ApiModelProperty("版本信息")
    private String changeContent;
    /**
     * 变更单据id
     */
    @ApiModelProperty("变更单据id")
    private Long objId;
    /**
     * 版本号
     */
    @ApiModelProperty("版本号")
    private Integer versionNo;
    /**
     * 变更状态
     */
    @ApiModelProperty("变更状态")
    private String status;
    /**
     * 流程状态
     */
    @ApiModelProperty("流程状态")
    private String apprStatus;
    /**
     * 流程实例ID
     */
    @ApiModelProperty("流程实例ID")
    private String procInstId;
    private String extString1;
    private String extString2;
    private String extString3;
    private String extString4;
    private String extString5;

    private PersonPlanVO personPlanVO;

    /**
     * 记录创建者ID
     */
    @ApiModelProperty("记录创建者ID")
    private Long createUserId;

    /**
     * 记录创建者名称
     */
    @ApiModelProperty("记录创建者名称")
    @UdcName(udcName = "USER",codePropName ="createUserId")
    private String createUserName;


}
